@@ -53,59 +53,62 @@ things, write your own code or use the wetware.
 #include "md5.h"
 
 void
-printbytes(const unsigned char* bytes, const int count)
+printbytes (const unsigned char *bytes, const int count)
 {
   int i;
 
   for (i = 0; i < count; i++)
-    printf("%2.2hx", *(bytes + i));
+    printf ("%2.2hx", *(bytes + i));
   return;
 }
 
 void
-scanbytes(const char* buf, unsigned char* bytes, const int count)
+scanbytes (const char *buf, unsigned char *bytes, const int count)
 {
   int i;
-  char s[]="0xxx" ;
+  char s[] = "0xxx";
 
-  for (i = 0; i < count; i++) {
-    s[2] = *(buf + 2*i) ;
-    s[3] = *(buf + 2*i + 1) ;
-    *(bytes + i) = (unsigned char) strtol(s, NULL, 16);
-  }
+  for (i = 0; i < count; i++)
+    {
+      s[2] = *(buf + 2 * i);
+      s[3] = *(buf + 2 * i + 1);
+      *(bytes + i) = (unsigned char) strtol (s, NULL, 16);
+    }
   return;
 }
 
 int
-main(void)
-{ /* IDEA-encrypt MD5-hash of subject line with MD5-hash of subjkey */
-  struct MD5Context subjkeyDigest, subjectDigest ;
-  struct IdeaCfbContext subjcontext ;
-  char subjkey[80], input[80], ctbuf[80] ;
-  unsigned char subjIDEAkey[16], subjPT[16] ;
-  unsigned char subjPT2[24], subjCT[24] ; /* includes IV */
+main (void)
+{
+  /* IDEA-encrypt MD5-hash of subject line with MD5-hash of subjkey.  */
+  struct MD5Context subjkeyDigest, subjectDigest;
+  struct IdeaCfbContext subjcontext;
+  char subjkey[80], input[80], ctbuf[80];
+  unsigned char subjIDEAkey[16], subjPT[16];
+  unsigned char subjPT2[24], subjCT[24];	/* Includes IV.  */
 
-  fgets(subjkey, sizeof(subjkey), stdin);
-  subjkey[strlen(subjkey) - 1] = '\0';
-  fgets(input, sizeof(input), stdin);
-  input[strlen(input) - 1] = '\0';
-  MD5Init(&subjkeyDigest);
-  MD5Update(&subjkeyDigest, subjkey, strlen(subjkey));
-  MD5Final(subjIDEAkey, &subjkeyDigest);
-  MD5Init(&subjectDigest);
-  MD5Update(&subjectDigest, input, strlen(input));
-  MD5Final(subjPT, &subjectDigest);
-  printf("Subject digest: ");
-  printbytes(subjPT, 16);
-  putc('\n', stdout);
-  while (fgets(ctbuf, sizeof(ctbuf), stdin)) {
-    scanbytes(ctbuf, subjCT, 24);
-    ideaCfbInit(&subjcontext, subjIDEAkey);
-    ideaCfbDecrypt(&subjcontext, subjCT, subjPT2, 24);
-    ideaCfbDestroy(&subjcontext);
-    printf("Subject: ");
-    printbytes(subjPT2 + 8, 16);
-    putc('\n', stdout);
-  }
+  fgets (subjkey, sizeof (subjkey), stdin);
+  subjkey[strlen (subjkey) - 1] = '\0';
+  fgets (input, sizeof (input), stdin);
+  input[strlen (input) - 1] = '\0';
+  MD5Init (&subjkeyDigest);
+  MD5Update (&subjkeyDigest, (unsigned char *) subjkey, strlen (subjkey));
+  MD5Final (subjIDEAkey, &subjkeyDigest);
+  MD5Init (&subjectDigest);
+  MD5Update (&subjectDigest, (unsigned char *) input, strlen (input));
+  MD5Final (subjPT, &subjectDigest);
+  printf ("Subject digest: ");
+  printbytes (subjPT, 16);
+  putc ('\n', stdout);
+  while (fgets (ctbuf, sizeof (ctbuf), stdin))
+    {
+      scanbytes (ctbuf, subjCT, 24);
+      ideaCfbInit (&subjcontext, subjIDEAkey);
+      ideaCfbDecrypt (&subjcontext, subjCT, subjPT2, 24);
+      ideaCfbDestroy (&subjcontext);
+      printf ("Subject: ");
+      printbytes (subjPT2 + 8, 16);
+      putc ('\n', stdout);
+    }
   return 1;
 }
